--- kstars/ekos/guide/internalguide/MPI_IS_gaussian_process/src/gaussian_process.cpp.orig	2025-12-01 12:06:11 UTC
+++ kstars/ekos/guide/internalguide/MPI_IS_gaussian_process/src/gaussian_process.cpp
@@ -18,6 +18,7 @@
  */
 
 #include <cstdint>
+#include <cassert>
 
 #include "gaussian_process.h"
 #include "math_tools.h"
